@@ -18,7 +18,7 @@ mod_fitting_micro_ui <- function(id, label) {
       box(
         width = 6,
         title = span(
-          "Data input options",
+          "1. Data input options",
           help_modal_button(
             ns("help_count_data"),
             ns("help_count_data_modal")
@@ -123,7 +123,7 @@ mod_fitting_micro_ui <- function(id, label) {
       box(
         width = 6,
         title = span(
-          "Fitting options",
+          "2. Fitting options",
           help_modal_button(
             ns("help_fitting_options"),
             ns("help_fitting_options_modal")
@@ -190,7 +190,7 @@ mod_fitting_micro_ui <- function(id, label) {
     fluidRow(
       box(
         width = 12,
-        title = "Irradiation conditions",
+        title = "3. Irradiation conditions",
         status = "primary",
         collapsible = TRUE,
         col_6(
@@ -203,17 +203,30 @@ mod_fitting_micro_ui <- function(id, label) {
           textAreaInput(
             inputId = ns("irr_cond_radiation_quality"),
             label = "Radiation quality",
-            placeholder = "X or gamma rays and energy"
+            placeholder = "e.g. Cs-137, Co-60, X-ray, etc."
           ),
-          textInput(
-            inputId = ns("irr_cond_dose_rate"),
+
+          numericInput(
+            ns("irr_cond_dose_rate"),
             label = "Dose rate (Gy/min)",
-            placeholder = NULL
+            step=0.1,
+            value = NA,
+            min=0
           ),
-          textInput(
-            inputId = ns("irr_cond_dose_quantity"),
+          selectInput(
+            ns("irr_cond_dose_quantity"),
             label = "Dose quantity",
-            placeholder = "In water or air kerma"
+            choices = c("Please choose"="", "air kerma", "dose to water", "dose to blood")
+          ),
+          selectInput(
+            ns("cal_air_water"),
+            label = "Calibration of the source",
+            choices = c("Please choose"="","air kerma", "water")
+          ),
+          selectInput(
+            ns("irrad_air_water"),
+            label = "Irradiation medium",
+            choices = c("Please choose"="","air", "water")
           )
         ),
         col_6(
@@ -223,20 +236,35 @@ mod_fitting_micro_ui <- function(id, label) {
             label = "Whole blood or isolated lymphocytes",
             placeholder = NULL
           ),
-          textInput(
-            inputId = ns("irr_cond_temperature"),
-            label = "Temperature",
-            placeholder = "Temperature during the irradiation"
+          numericInput(
+            ns("irr_cond_temperature"),
+            label = "Temperature (\u00B0C) during irradiation",
+            step=1,
+            value = NA,
+            min=0,
+            max = 40
           ),
-          textInput(
-            inputId = ns("irr_cond_time"),
-            label = "Time incubations",
-            placeholder = "Time incubations after sample irradiation"
+          numericInput(
+            ns("irr_cond_time"),
+            label = "Time of incubation (h) at 37(\u00B0C) after irradiation"  ,
+            step=1,
+            value = NA,
+            min=0
           ),
           textAreaInput(
             inputId = ns("irr_cond_beam_characteristics"),
             label = "Beam characteristics",
             placeholder = "Beam quality indicators, filtration (X-rays), energy (Gamma rays), ..."
+          ),
+          selectInput(
+            ns("scoring_method"),
+            label = "Scoring method",
+            choices = c("Please choose"="","manual", "auto")
+          ),
+          textInput(
+            inputId = ns("origin_curve"),
+            label = "Origin of the curve",
+            placeholder = "e.g. own, IAEA ..."
           )
         )
       )
@@ -246,7 +274,7 @@ mod_fitting_micro_ui <- function(id, label) {
     fluidRow(
       box(
         width = 12,
-        title = "Data input",
+        title = "4. Data input",
         status = "primary",
         collapsible = TRUE,
         div(
@@ -337,7 +365,7 @@ mod_fitting_micro_ui <- function(id, label) {
         box(
           width = 12,
           title = span(
-            "Export results",
+            "5. Export results",
             help_modal_button(
               ns("help_fit_data_save"),
               ns("help_fit_data_save_modal")
@@ -433,8 +461,8 @@ mod_fitting_micro_ui <- function(id, label) {
             ns("save_plot_format"),
             label = NULL,
             width = "75px",
-            choices = list(".png", ".pdf"),
-            selected = ".png"
+            choices = list(".jpg", ".png",".pdf"),
+            selected = ".jpg"
           )
         )
       )
